package com.qianhe.system.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.qianhe.common.utils.DateUtils;
import com.qianhe.common.utils.StringUtils;
import com.qianhe.system.domain.WaterGoods;
import com.qianhe.system.domain.WaterGoodsImg;
import com.qianhe.system.domain.WaterGoodsSpe;
import com.qianhe.system.domain.WaterGoodsSpeVal;
import com.qianhe.system.mapper.WaterGoodsImgMapper;
import com.qianhe.system.mapper.WaterGoodsMapper;
import com.qianhe.system.mapper.WaterGoodsSpeMapper;
import com.qianhe.system.service.IWaterGoodsService;
import com.qianhe.system.vo.WaterGoodsSpeVo;
import com.qianhe.system.vo.WaterGoodsVo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * 商品Service业务层处理
 *
 * @author qianhe
 * @date 2023-11-23
 */
@Service
public class WaterGoodsServiceImpl implements IWaterGoodsService
{
    @Autowired
    private WaterGoodsMapper waterGoodsMapper;
    @Autowired
    private WaterGoodsSpeMapper waterGoodsSpeMapper;
    @Autowired
    private WaterGoodsImgMapper waterGoodsImgMapper;

    /**
     * 查询商品
     *
     * @param id 商品主键
     * @return 商品
     */
    @Override
    public WaterGoodsVo selectWaterGoodsById(Long id)
    {
        WaterGoods waterGoods = waterGoodsMapper.selectWaterGoodsById(id);
        //转vo
        WaterGoodsVo waterGoodsVo = new WaterGoodsVo();
        BeanUtils.copyProperties(waterGoods,waterGoodsVo);
        //查询商品图片
        WaterGoodsImg waterGoodsImg = new WaterGoodsImg();
        waterGoodsImg.setGoodsId(id);
        List<WaterGoodsImg> waterGoodsImgs = waterGoodsImgMapper.selectWaterGoodsImgList(waterGoodsImg);
        //查询商品规格
        WaterGoodsSpe waterGoodsSpe = new WaterGoodsSpe();
        waterGoodsSpe.setGoodsId(id);
        List<WaterGoodsSpe> waterGoodsSpes = waterGoodsSpeMapper.selectWaterGoodsSpeList(waterGoodsSpe);
        List<WaterGoodsSpeVo> waterGoodsSpeVoList = new ArrayList<>();
        if (waterGoodsSpes.size() > 0){
            for (WaterGoodsSpe goodsSpe : waterGoodsSpes) {
                //转vo
                WaterGoodsSpeVo waterGoodsSpeVo = new WaterGoodsSpeVo();
                BeanUtils.copyProperties(goodsSpe,waterGoodsSpeVo);

                WaterGoodsSpeVal waterGoodsSpeVal = new WaterGoodsSpeVal();
                waterGoodsSpeVal.setSpeId(goodsSpe.getId());
                List<WaterGoodsSpeVal> waterGoodsSpeVals = waterGoodsSpeMapper.selectWaterGoodsSpeValList(waterGoodsSpeVal);
                if (waterGoodsSpeVals.size() > 0){
                    waterGoodsSpeVo.setWaterGoodsSpeValList(waterGoodsSpeVals);
                }
                waterGoodsSpeVoList.add(waterGoodsSpeVo);
            }
        }
        if (waterGoodsSpeVoList.size() > 0){
            waterGoodsVo.setWaterGoodsSpe(waterGoodsSpeVoList.get(0));
        }
        List<WaterGoodsImg> coverImgs = new ArrayList<>();
        List<WaterGoodsImg> detailsImgs = new ArrayList<>();
        for (WaterGoodsImg waterGoodsImg1 : waterGoodsImgs) {
            if (waterGoodsImg1.getImgType() == 1){
                //商品封面图
                coverImgs.add(waterGoodsImg1);
            }
            if (waterGoodsImg1.getImgType() == 2){
                //商品详情图
                detailsImgs.add(waterGoodsImg1);
            }
        }
        if (coverImgs.size() > 0){
            waterGoodsVo.setCoverImgs(coverImgs);
        }
        if (detailsImgs.size() > 0){
            waterGoodsVo.setDetailsImgs(detailsImgs);
        }
        return waterGoodsVo;
    }

    /**
     * 查询商品列表
     *
     * @param waterGoods 商品
     * @return 商品
     */
    @Override
    public List<WaterGoods> selectWaterGoodsList(WaterGoods waterGoods)
    {
        return waterGoodsMapper.selectWaterGoodsList(waterGoods);
    }

    /**
     * 新增商品
     *
     * @param waterGoodsVo 商品
     * @return 结果
     */
    @Override
    @Transactional
    public int insertWaterGoods(WaterGoodsVo waterGoodsVo)
    {
        waterGoodsVo.setCreateUser("管理员");
        waterGoodsVo.setCreateTime(DateUtils.getNowDate());
        int i = waterGoodsMapper.insertWaterGoods(waterGoodsVo);
        //新增封面图
        insertGoodsCoverImgs(waterGoodsVo);
        //新增详情图
        insertGoodsDetailsImgs(waterGoodsVo);
        //新增商品关联规格
        insertWaterGoodsSpe(waterGoodsVo);
        return i;
    }
    /**
     * 修改商品
     *
     * @param waterGoodsVo 商品
     * @return 结果
     */
    @Override
    public int updateWaterGoods(WaterGoodsVo waterGoodsVo)
    {
        //删除商品图片
        waterGoodsMapper.deleteWaterGoodsImgByGoodsId(waterGoodsVo.getId());
        //删除商品关联规格
        waterGoodsMapper.deleteWaterGoodsSpeByGoodsId(waterGoodsVo.getId());
        //新增封面图
        insertGoodsCoverImgs(waterGoodsVo);
        //新增详情图
        insertGoodsDetailsImgs(waterGoodsVo);
        //新增商品关联规格
        insertWaterGoodsSpe(waterGoodsVo);
        return waterGoodsMapper.updateWaterGoods(waterGoodsVo);
    }

    /**
     * 新增商品关联规格
     * @param waterGoodsVo
     */
    private void insertWaterGoodsSpe(WaterGoodsVo waterGoodsVo) {
        WaterGoodsSpeVo waterGoodsSpe = waterGoodsVo.getWaterGoodsSpe();
        //新增商品关联规格
        if (StringUtils.isNotNull(waterGoodsSpe)){
            waterGoodsSpe.setGoodsId(waterGoodsVo.getId());
            waterGoodsSpe.setCreateUser("管理员");
            waterGoodsSpe.setCreateTime(DateUtils.getNowDate());
            waterGoodsSpeMapper.insertWaterGoodsSpe(waterGoodsSpe);
        }
        List<WaterGoodsSpeVal> waterGoodsSpeValList = waterGoodsSpe.getWaterGoodsSpeValList();
        List<WaterGoodsSpeVal> waterGoodsSpeVals = new ArrayList<>();
        //商品关联规格主键id
        Long speId = waterGoodsSpe.getId();

        if (StringUtils.isNotNull(waterGoodsSpeValList)){
            for (WaterGoodsSpeVal waterGoodsSpeVal : waterGoodsSpeValList) {
                waterGoodsSpeVal.setSpeId(speId);
                waterGoodsSpeVals.add(waterGoodsSpeVal);
            }
        }
        if (waterGoodsSpeVals.size() > 0){
            //批量新增商品关联规格值
            waterGoodsSpeMapper.batchInsertWaterGoodsSpeVal(waterGoodsSpeVals);
        }
    }

    /**
     * 新增详情图
     * @param waterGoodsVo
     */
    private void insertGoodsDetailsImgs(WaterGoodsVo waterGoodsVo) {
        List<WaterGoodsImg> detailsImgs = waterGoodsVo.getDetailsImgs();

        List<WaterGoodsImg> detailsImgList = new ArrayList<>();
        //商品主键id
        Long id = waterGoodsVo.getId();
        if (StringUtils.isNotNull(detailsImgs)){
            for (WaterGoodsImg detailsImg : detailsImgs) {
                detailsImg.setGoodsId(id);
                detailsImg.setImgType(2);
                detailsImgList.add(detailsImg);
            }
        }
        if (detailsImgList.size() > 0){
            //批量新增详情图
            waterGoodsMapper.batchInsertWaterGoodsImg(detailsImgList);
        }
    }

    /**
     * 新增封面图
     * @param waterGoodsVo
     */
    private void insertGoodsCoverImgs(WaterGoodsVo waterGoodsVo) {
        List<WaterGoodsImg> coverImgs = waterGoodsVo.getCoverImgs();

        List<WaterGoodsImg> coverImgList = new ArrayList<>();
        //商品主键id
        Long id = waterGoodsVo.getId();
        if (StringUtils.isNotNull(coverImgs)){
            for (WaterGoodsImg coverImg : coverImgs) {
                coverImg.setGoodsId(id);
                coverImg.setImgType(1);
                coverImgList.add(coverImg);
            }
        }
        if (coverImgList.size() > 0){
            //批量新增封面图
            waterGoodsMapper.batchInsertWaterGoodsImg(coverImgList);
        }
    }

    /**
     * 批量删除商品
     *
     * @param ids 需要删除的商品主键
     * @return 结果
     */
    @Override
    public int deleteWaterGoodsByIds(Long[] ids)
    {
        //删除商品图片
        waterGoodsMapper.deleteWaterGoodsImgByGoodsIds(ids);
        //删除商品关联规格
        waterGoodsMapper.deleteWaterGoodsSpeByGoodsIds(ids);
        return waterGoodsMapper.deleteWaterGoodsByIds(ids);
    }

    /**
     * 删除商品信息
     *
     * @param id 商品主键
     * @return 结果
     */
    @Override
    public int deleteWaterGoodsById(Long id)
    {
        return waterGoodsMapper.deleteWaterGoodsById(id);
    }
}
