package com.qianhe.system.service.impl;

import com.qianhe.common.utils.DateUtils;
import com.qianhe.system.domain.WaterOrder;
import com.qianhe.system.mapper.WaterOrderMapper;
import com.qianhe.system.service.IWaterOrderService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 订单Service业务层处理
 *
 * @author qianhe
 * @date 2023-11-23
 */
@Service
public class WaterOrderServiceImpl implements IWaterOrderService
{
    @Autowired
    private WaterOrderMapper waterOrderMapper;

    /**
     * 查询订单
     *
     * @param id 订单主键
     * @return 订单
     */
    @Override
    public WaterOrder selectWaterOrderById(Long id)
    {
        return waterOrderMapper.selectWaterOrderById(id);
    }

    /**
     * 查询订单列表
     *
     * @param waterOrder 订单
     * @return 订单
     */
    @Override
    public List<WaterOrder> selectWaterOrderList(WaterOrder waterOrder)
    {
        return waterOrderMapper.selectWaterOrderList(waterOrder);
    }

    /**
     * 新增订单
     *
     * @param waterOrder 订单
     * @return 结果
     */
    @Override
    public int insertWaterOrder(WaterOrder waterOrder)
    {
        waterOrder.setCreateTime(DateUtils.getNowDate());
        return waterOrderMapper.insertWaterOrder(waterOrder);
    }

    /**
     * 修改订单
     *
     * @param waterOrder 订单
     * @return 结果
     */
    @Override
    public int updateWaterOrder(WaterOrder waterOrder)
    {
        return waterOrderMapper.updateWaterOrder(waterOrder);
    }

    /**
     * 批量删除订单
     *
     * @param ids 需要删除的订单主键
     * @return 结果
     */
    @Override
    public int deleteWaterOrderByIds(Long[] ids)
    {
        return waterOrderMapper.deleteWaterOrderByIds(ids);
    }

    /**
     * 删除订单信息
     *
     * @param id 订单主键
     * @return 结果
     */
    @Override
    public int deleteWaterOrderById(Long id)
    {
        return waterOrderMapper.deleteWaterOrderById(id);
    }
}
